/* XQF - Quake server browser and launcher
 * Copyright (C) 1998 Roman Pozlevich <roma@botik.ru>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 */

#ifndef __SOURCE_H__
#define __SOURCE_H__

#include "xqf.h"


extern	GSList *qw_masters;
extern	GSList *q2_masters;
extern  struct master *unbound_qw;
extern	struct master *unbound_q2;
extern	struct master *qw_sources;
extern	struct master *q2_sources;
extern	struct master *allsources;
extern	struct master *favorites;


extern	void save_server_list (struct master *m);

extern	void init_masters (void);
extern	void free_masters (void);

extern	void add_server_to_master (struct master *m, struct server *s);
extern	void remove_server_from_master (struct master *m, struct server *s);

extern	GSList *collate_server_lists (GSList *servers, GSList *sources,
                                                      enum server_type type);
extern	GSList *server_sources (struct server *s);

extern	char *game_type_str (enum server_type st);


#endif /* __SOURCE_H__ */


